Community Apps - Nautobot Documentation

Skip to content

# Nautobot Community Apps

The following is a manually curated list of Apps from the wider Nautobot community, which have some sort of documentation.

App Name | Links | Description
--- | --- | ---
Nautobot SSoT vSphere | Docs GitHub | An App for Nautobot that leverages the SSoT App to create Virtual Machines, VMInterfaces, IPAddresses, Clusters, and Cluster Groups from VMWare vSphere.
GWDG Networking Team Plugins | GitLab | nautobot-move nautobot-bulk-connect nautobot-cable-utils nautobot-evpn nautobot-sfp-inventory nautobot-type-reapply and more.